function [model,removedCoeffs,discartedMets] = processBiomassRxnCbModel_OCTAVE(model,objIdx,tol)
% Remove trace elements from biomass equation
% Inputs:  model structure LP, biomass rxn index, numerical tol (e.g. 1e-3)
%
% Outputs: model pre-processed, removed coeffs vector, discarted mets from
%          the biomass equation
%%%%%%%%%%%%%%%%%%%%%% Pedro Saa UQ 2015 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
params.tolint  = 1e-8;           % Optimization parameters (GLPK)
params.tolobj  = 1e-8;
params.tolbnd  = 1e-8;    
params.toldj   = 1e-8; 
model.obj(objIdx) = 1;
model.sense       = -1; % maximization
[~,initF]         = glpk(model.obj,model.A,model.rhs,model.lb,model.ub,model.ctype,model.vartype,model.sense,params);
discartedMets     = find((model.A(:,objIdx)~=0).*(abs(model.A(:,objIdx))<tol));
removedCoeffs     = model.A(discartedMets,objIdx);
model.A(discartedMets,objIdx) = 0;
model.S           = model.A;

% Compare initial and final solutions
[~,finalF] = glpk(model.obj,model.A,model.rhs,model.lb,model.ub,model.ctype,model.vartype,model.sense,params);
disp(['Relative difference in obj fxn: ',num2str(100*abs(1-finalF/initF))]);