function closestPoint = findClosestFeasiblePoint(model,queryPoint)
% Finds closest feasible center point
% Inputs:  model   (MILP formulation)
% Outputs: modelLP (LP formulation)
%%%%%%%%%%%%%%%%%%%%%% Pedro Saa UQ 2015 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Assign previous structure
modelMIQP = model;
n = model.numRxns;
m = model.internal(end);
K = 1e4;
params.outputflag     = 0;
params.OptimalityTol  = 1e-9;
params.FeasibilityTol = 1e-9;
params.IntFeasTol     = 1e-9;
params.MIPGap         = 1e-12;
params.MIPGapAbs      = 1e-12;
params.TimeLimit      = 5*60; % Time less than 5 min (otherwise try simpler MILP)
numTol                = 1e-8;

% Add slacks for flux vectors
modelMIQP.A   = sparse([model.A,zeros(size(model.A,1),n);...
    eye(n),zeros(n,2*m),-eye(n)]);
modelMIQP.obj = zeros(size(modelMIQP.A,2),1);
modelMIQP.Q   = sparse([zeros(n+2*m,2*n+2*m);zeros(n,n+2*m),eye(n)]);

% Update remaining fields
modelMIQP.rhs = [modelMIQP.rhs;queryPoint];
modelMIQP.lb  = [modelMIQP.lb;-K*ones(n,1)];
modelMIQP.ub  = [modelMIQP.ub;K*ones(n,1)];
modelMIQP.vtype      = [modelMIQP.vtype,repmat('C',1,n)];
modelMIQP.sense      = [modelMIQP.sense,repmat('=',1,n)];
modelMIQP.modelsense = 'min';

% Find closest point to the query
sol = gurobi(modelMIQP,params);
if strcmp(sol.status,'OPTIMAL')
    sol.x(abs(sol.x)<numTol) = 0;
    closestPoint = sol.x(1:n);
else
    disp('Timeout closest center. Finding random interior point instead...');
    
    % Find random interior point
    closestPoint = getInteriorPoint(model,0.95,params);
end